@@ -20,18 +20,17 @@ from bittrade_cryptodotcom_websocket import (
     EnhancedWebsocketBehaviorSubject,
     subscribe_order_book,
     subscribe_open_orders,
-    
 )
 from bittrade_cryptodotcom_websocket.models import (
     UserBalance,
-    CryptodotcomRequestMessage
+    CryptodotcomRequestMessage,
 )
 
 from bittrade_cryptodotcom_websocket.rest import (
     get_user_balance_factory,
-    get_deposit_address_factory,
     create_order_factory,
     cancel_all_factory,
+    cancel_order_factory,
     get_user_open_orders_factory,
     close_position_factory,
 )
@@ -39,16 +38,22 @@ from ccxt import cryptocom
 
 logger = getLogger(__name__)
 
+
 @dataclass
 class CryptodotcomContext:
     all_subscriptions: CompositeDisposable
     books: dict[str, Observable[list[tuple[str, str]]]]
-    cancel_all: Callable[[str, Literal['trigger', 'limit', 'all']], Observable[bool]]
-    close_position: Callable[[str, Literal['market', 'limit'], Optional[str]], Observable[int]]
-    create_order: Callable[[str, str, str, float, Optional[float], Optional[Any]], Observable[dict[str, Any]]]
+    cancel_all: Callable[[str, Literal["trigger", "limit", "all"]], Observable[bool]]
+    cancel_order: Callable[[str], Observable[bool]]
+    close_position: Callable[
+        [str, Literal["market", "limit"], Optional[str]], Observable[int]
+    ]
+    create_order: Callable[
+        [str, str, str, float, Optional[float], Optional[Any]],
+        Observable[dict[str, Any]],
+    ]
     exchange: cryptocom
     feed_messages: Observable[CryptodotcomResponseMessage]
-    get_deposit_address: Callable[[], Observable[list[dict]]]
     get_user_balance: Callable[[], Observable[list[UserBalance]]]
     get_user_open_orders: Callable[[Optional[str]], Observable]
     guaranteed_websocket: Observable[EnhancedWebsocket]
@@ -63,7 +68,10 @@ class CryptodotcomContext:
 
 @contextmanager
 def cryptodotcom_sockets(
-    add_token: Callable[[Observable[CryptodotcomResponseMessage]], Callable[[EnhancedWebsocket], Observable[EnhancedWebsocket]]],
+    add_token: Callable[
+        [Observable[CryptodotcomResponseMessage]],
+        Callable[[EnhancedWebsocket], Observable[EnhancedWebsocket]],
+    ],
     books: Optional[tuple[tuple[str, int]]] = None,
 ):
     books = books or ()  # type: ignore
@@ -84,20 +92,15 @@ def cryptodotcom_sockets(
         flat_map(add_token(private_messages)),
         share(),
     )
-    response_messages = private_messages.pipe(
-        keep_response_messages_only(),
-        share()
-    )
-    feed_messages = private_messages.pipe(
-        exclude_response_messages(),
-        share()
-    )
+    response_messages = private_messages.pipe(keep_response_messages_only(), share())
+    feed_messages = private_messages.pipe(exclude_response_messages(), share())
 
     book_observables = {}
-    for pair, depth in books:
-        book_observables[f'{pair}_{depth}'] = public_sockets.pipe(
-            keep_new_socket_only(), subscribe_order_book(pair, str(depth), public_messages),  # type: ignore
-            share()
+    for pair, depth in books or ():
+        book_observables[f"{pair}_{depth}"] = public_sockets.pipe(
+            keep_new_socket_only(),
+            subscribe_order_book(pair, str(depth), public_messages),  # type: ignore
+            share(),
         )
 
     socket_bs: EnhancedWebsocketBehaviorSubject = BehaviorSubject(
@@ -107,24 +110,25 @@ def cryptodotcom_sockets(
     guaranteed_socket = socket_bs.pipe(
         operators.filter(lambda x: bool(x)),
     )
-    get_user_open_orders = get_user_open_orders_factory(response_messages, socket_bs, exchange)
+    get_user_open_orders = get_user_open_orders_factory(
+        response_messages, socket_bs, exchange
+    )
     open_orders = guaranteed_socket.pipe(
-        subscribe_open_orders(private_messages, exchange),
-        share()
-    )
-    open_orders_reloaded = open_orders.pipe(
-        flat_map(lambda _: get_user_open_orders())
+        subscribe_open_orders(private_messages, exchange), share()
     )
+    open_orders_reloaded = open_orders.pipe(flat_map(lambda _: get_user_open_orders()))
 
     context = CryptodotcomContext(
         all_subscriptions=all_subscriptions,
         books=book_observables,
-        cancel_all=cancel_all_factory(response_messages, open_orders, exchange, socket_bs),
+        cancel_all=cancel_all_factory(
+            response_messages, open_orders, exchange, socket_bs
+        ),
+        cancel_order=cancel_order_factory(private_messages, socket_bs),
         close_position=close_position_factory(response_messages, exchange, socket_bs),
         create_order=create_order_factory(private_messages, exchange, socket_bs),
         exchange=exchange,
         feed_messages=feed_messages,
-        get_deposit_address=get_deposit_address_factory(response_messages, socket_bs),
         get_user_balance=get_user_balance_factory(response_messages, socket_bs),
         get_user_open_orders=get_user_open_orders,
         guaranteed_websocket=guaranteed_socket,
